@@ -96,12 +96,12 @@ def init(http_host: str ,exp_name: str="", team_name: str="", run_name: str="",
 
     # sysInfo값을 넘겨주어 rest api의 인자인 sysInfo필드에 넣어주도록 한다
     sys_info = {
-        "os": security.get_os(),
-        "python": security.get_python_version(),
-        "gpu": security.get_gpu(),
-        "gpuCount": security.get_gpu_count(),
-        "cpuCount": security.get_cpu_count(),
-        "hostname": security.get_hostname(),
+        "os": util.get_os(),
+        "python": util.get_python_version(),
+        "gpu": util.get_gpu(),
+        "gpuCount": util.get_gpu_count(),
+        "cpuCount": util.get_cpu_count(),
+        "hostname": util.get_hostname(),
     }
 
     # Interface.py의 init 함수 호출 후 응답받은 데이터로 부터 실험환경 이름과 팀이름, 실행이름, 실행ID, 대쉬보드URL을 가져와 Run 객체에 설정하고 반환한다.
@@ -109,7 +109,7 @@ def init(http_host: str ,exp_name: str="", team_name: str="", run_name: str="",
         "teamName": team_name,
         "expName": exp_name,
         "runName": run_name,
-        "config": {"cliVer": version.__version__, "pythonVer": security.get_python_version(), "_custom": _custom},
+        "config": {"cliVer": version.__version__, "pythonVer": util.get_python_version(), "_custom": _custom},
         "sysInfo": sys_info,
         "createRun": "Y",
     }
@@ -124,14 +124,14 @@ def create_hpo(http_host:str, exp_name: str="", team_name: str="", hpo_config: D
     data ={
         "teamName": team_name,
         "expName": exp_name,
-        "config":  {"cliVer": version.__version__, "pythonVer": security.get_python_version(), "hpoConfig": hpo_config},
+        "config":  {"cliVer": version.__version__, "pythonVer": util.get_python_version(), "hpoConfig": hpo_config},
         "sysInfo": {
-            "os": security.get_os(),
-            "python": security.get_python_version(),
-            "gpu": security.get_gpu(),
-            "gpuCount": security.get_gpu_count(),
-            "cpuCount": security.get_cpu_count(),
-            "hostname": security.get_hostname(),
+            "os": util.get_os(),
+            "python": util.get_python_version(),
+            "gpu": util.get_gpu(),
+            "gpuCount": util.get_gpu_count(),
+            "cpuCount": util.get_cpu_count(),
+            "hostname": util.get_hostname(),
         },
     }
     url = parse_result_wraaper(http_host,URL_CREATE_HPO)
